@@ -74,3 +74,24 @@ class BasePo(object):
             raise PlaywrightTimeoutError(f"元素 '{selector}' 未在 {timeout} 秒内找到")
         except Exception as e:
             raise RuntimeError(f"检查元素时发生错误: {str(e)}")
+
+    async def get_sub_locator(self, locator: Locator, selector: str, timeout: float = 3.0) -> Locator:
+        """
+        获取页面locator的子locator
+        :param locator: 页面Locator对象
+        :param selector: 选择器表达式
+        :param timeout: 超时时间（秒）
+        :return: 元素对象
+        :return:
+        """
+        try:
+            locator_inner = locator.locator(selector)
+            if await self.exists(locator=locator_inner):
+                await locator_inner.first.wait_for(state='visible', timeout=timeout * 1000)
+                return locator_inner
+            else:
+                raise RuntimeError(f"根据selector: {selector}，在页面Locator对象中没有查找对应的子Locator对象")
+        except (PlaywrightTimeoutError,):
+            raise PlaywrightTimeoutError(f"元素 '{selector}' 未在 {timeout} 秒内找到")
+        except Exception as e:
+            raise RuntimeError(f"检查元素时发生错误: {str(e)}")
